sn property
A 4-byte timestamp, representing the ObjectId's creation, measured in seconds since the Unix epoch. A 5-byte random value generated once per process. This random value is unique to the machine and process. A 3-byte incrementing counter, initialized to a random value. according to mongodb ids
Implementation
@$pb.TagNumber(1)
$core.String get sn => $_getSZ(0);
Implementation
@$pb.TagNumber(1)
set sn($core.String v) {
$_setString(0, v);
}