flashEncrypted property
true if flash encryption is enabled on the device
Implementation
@$pb.TagNumber(12)
$core.bool get flashEncrypted => $_getBF(11);
Implementation
@$pb.TagNumber(12)
set flashEncrypted($core.bool v) {
$_setBool(11, v);
}
true if flash encryption is enabled on the device
@$pb.TagNumber(12)
$core.bool get flashEncrypted => $_getBF(11);
@$pb.TagNumber(12)
set flashEncrypted($core.bool v) {
$_setBool(11, v);
}